==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/MiejscePobytu.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class MiejscePobytu extends GenericDPSObject {
    /**
     * MIEJSCE_POBYTU.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * MIEJSCE_POBYTU.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * MIEJSCE_POBYTU.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean opiekaZdrowotna;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MIEJSCE_POBYTU.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * MIEJSCE_POBYTU.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return MIEJSCE_POBYTU.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * MIEJSCE_POBYTU.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return MIEJSCE_POBYTU.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * MIEJSCE_POBYTU.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getOpiekaZdrowotna() {
        return opiekaZdrowotna;
    }

    /**
     * MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     *
     * @param opiekaZdrowotna
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpiekaZdrowotna(Boolean opiekaZdrowotna) {
        this.opiekaZdrowotna = opiekaZdrowotna;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        MiejscePobytu other = (MiejscePobytu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpiekaZdrowotna() == null ? other.getOpiekaZdrowotna() == null : this.getOpiekaZdrowotna().equals(other.getOpiekaZdrowotna()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpiekaZdrowotna() == null) ? 0 : getOpiekaZdrowotna().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opiekaZdrowotna=").append(opiekaZdrowotna);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/MiejscePobytu.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class MiejscePobytu extends GenericDPSObject {
    /**
     * MIEJSCE_POBYTU.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * MIEJSCE_POBYTU.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * MIEJSCE_POBYTU.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean opiekaZdrowotna;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MIEJSCE_POBYTU.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * MIEJSCE_POBYTU.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return MIEJSCE_POBYTU.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * MIEJSCE_POBYTU.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return MIEJSCE_POBYTU.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * MIEJSCE_POBYTU.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getOpiekaZdrowotna() {
        return opiekaZdrowotna;
    }

    /**
     * MIEJSCE_POBYTU.OPIEKA_ZDROWOTNA
     *
     * @param opiekaZdrowotna
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpiekaZdrowotna(Boolean opiekaZdrowotna) {
        this.opiekaZdrowotna = opiekaZdrowotna;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        MiejscePobytu other = (MiejscePobytu) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpiekaZdrowotna() == null ? other.getOpiekaZdrowotna() == null : this.getOpiekaZdrowotna().equals(other.getOpiekaZdrowotna()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpiekaZdrowotna() == null) ? 0 : getOpiekaZdrowotna().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opiekaZdrowotna=").append(opiekaZdrowotna);
        sb.append("]");
        return sb.toString();
    }
}
